==> qmmp-0.8.4.tar.bz2: qmmp-0.8.4/src/plugins/General/udisks/translations/udisks_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>CD Ses Algılama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Parçaları listeye otomatik olarka ekle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Parçaları listeden otomatik olarak kaldır</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Çıkarılabilir Aygıt Algılama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Dosyaları listeye otomatik olarak ekle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Dosyaları listeden otomatik olarak kaldır</translation>
    </message>
</context>
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="30"/>
        <source>UDisks Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="50"/>
        <source>About UDisks Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="51"/>
        <source>Qmmp UDisks Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="154"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="160"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/General/udisks/translations/udisks_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>CD Ses Algılama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Parçaları listeye otomatik olarka ekle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Parçaları listeden otomatik olarak kaldır</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Çıkarılabilir Aygıt Algılama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Dosyaları listeye otomatik olarak ekle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Dosyaları listeden otomatik olarak kaldır</translation>
    </message>
</context>
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="32"/>
        <source>UDisks Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>About UDisks Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>Qmmp UDisks Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="54"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished">Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="154"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation type="unfinished">CD &quot;%1&quot; Ekle</translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="160"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation type="unfinished">&quot;%1&quot; Aygıtını Ekle</translation>
    </message>
</context>
</TS>
